Header menu logo Xanthos

SilksImage Type

Represents a retrieved silks (勝負服) image via JVFukuFile.

Silks images show the jockey's racing colors for visual identification. Either FilePath (saved to disk) or Data (in-memory) will be populated.

Record fields

Record Field Description

Data

Full Usage: Data

Field type: byte[] option

Raw image data as bytes, if loaded in memory.

Field type: byte[] option

FilePath

Full Usage: FilePath

Field type: string option

Path to the saved silks image file, if saved to disk.

Field type: string option

Type something to start searching.