Header menu logo Xanthos

WatchEventRealtimeRequest Type

Represents the dataspec/key pair required to issue JVRTOpen after a watch event.

After receiving a watch event, use this request to fetch the associated real-time data. The Dataspec identifies the data type, and Key specifies the exact record.

Record fields

Record Field Description

Dataspec

Full Usage: Dataspec

Field type: string

JV-Data specification code (e.g., "0B11", "0B12", "0B16").

Field type: string

Key

Full Usage: Key

Field type: string

Record key for the JVRTOpen call.

Field type: string

Type something to start searching.