Header menu logo Xanthos

WatchEventType Type

Represents the different event notifications emitted by JVWatchEvent.

JVWatchEvent is a real-time notification API that pushes updates during live race days. Each event type corresponds to a specific dataspec for retrieving the associated data. See dataspecForEvent for the dataspec mappings.

Union cases

Union case Description

AvoidedRace

Full Usage: AvoidedRace

Race avoided/cancelled (発走除外). Dataspec: 0B16.

CourseChange

Full Usage: CourseChange

Course/track change (コース変更). Dataspec: 0B16.

HorseWeight

Full Usage: HorseWeight

Horse weight announced (馬体重発表). Dataspec: 0B11.

JockeyChange

Full Usage: JockeyChange

Jockey change (騎手変更). Dataspec: 0B16.

PayoffConfirmed

Full Usage: PayoffConfirmed

Payoff/dividend results confirmed (払戻確定). Dataspec: 0B12.

StartTimeChange

Full Usage: StartTimeChange

Post time change (発走時刻変更). Dataspec: 0B16.

UnknownEvent string

Full Usage: UnknownEvent string

Parameters:
    Item : string

Unknown or unrecognized event type with the raw event string.

Item : string

WeatherChange

Full Usage: WeatherChange

Weather condition change (天候変更). Dataspec: 0B16.

Instance members

Instance member Description

this.IsAvoidedRace

Full Usage: this.IsAvoidedRace

Returns: bool
Returns: bool

this.IsCourseChange

Full Usage: this.IsCourseChange

Returns: bool
Returns: bool

this.IsHorseWeight

Full Usage: this.IsHorseWeight

Returns: bool
Returns: bool

this.IsJockeyChange

Full Usage: this.IsJockeyChange

Returns: bool
Returns: bool

this.IsPayoffConfirmed

Full Usage: this.IsPayoffConfirmed

Returns: bool
Returns: bool

this.IsStartTimeChange

Full Usage: this.IsStartTimeChange

Returns: bool
Returns: bool

this.IsUnknownEvent

Full Usage: this.IsUnknownEvent

Returns: bool
Returns: bool

this.IsWeatherChange

Full Usage: this.IsWeatherChange

Returns: bool
Returns: bool

Type something to start searching.