IComDispatchProvider Type
Implemented by types that can expose their underlying COM dispatcher instance.
Instance members
| Instance member |
Description
|
|
|
Implemented by types that can expose their underlying COM dispatcher instance.
| Instance member |
Description
|
|
|