WatchEventRealtimeRequest Type
Represents the dataspec/key pair required to issue JVRTOpen after a watch event.
After receiving a watch event, use this request to fetch the associated real-time data. The Dataspec identifies the data type, and Key specifies the exact record.
Xanthos