WatchEventType Type
Represents the different event notifications emitted by JVWatchEvent.
JVWatchEvent is a real-time notification API that pushes updates during live race days. Each event type corresponds to a specific dataspec for retrieving the associated data. See dataspecForEvent for the dataspec mappings.
Union cases
| Union case |
Description
|
Full Usage:
AvoidedRace
|
Race avoided/cancelled (発走除外). Dataspec: 0B16. |
Full Usage:
CourseChange
|
Course/track change (コース変更). Dataspec: 0B16. |
Full Usage:
HorseWeight
|
Horse weight announced (馬体重発表). Dataspec: 0B11. |
Full Usage:
JockeyChange
|
Jockey change (騎手変更). Dataspec: 0B16. |
Full Usage:
PayoffConfirmed
|
Payoff/dividend results confirmed (払戻確定). Dataspec: 0B12. |
Full Usage:
StartTimeChange
|
Post time change (発走時刻変更). Dataspec: 0B16. |
Full Usage:
UnknownEvent string
Parameters:
string
|
Unknown or unrecognized event type with the raw event string.
|
Full Usage:
WeatherChange
|
Weather condition change (天候変更). Dataspec: 0B16. |
Instance members
| Instance member |
Description
|
Full Usage:
this.IsAvoidedRace
Returns: bool
|
|
Full Usage:
this.IsCourseChange
Returns: bool
|
|
Full Usage:
this.IsHorseWeight
Returns: bool
|
|
Full Usage:
this.IsJockeyChange
Returns: bool
|
|
Full Usage:
this.IsPayoffConfirmed
Returns: bool
|
|
Full Usage:
this.IsStartTimeChange
Returns: bool
|
|
Full Usage:
this.IsUnknownEvent
Returns: bool
|
|
Full Usage:
this.IsWeatherChange
Returns: bool
|
|
Xanthos