JvLinkStub Type
In-memory JV-Link emulator suitable for deterministic unit and property tests.
Constructors
| Constructor |
Description
|
|
|
Full Usage:
JvLinkStub(responses, ?totalSize, ?initialTimestamp)
Parameters:
Result<JvReadOutcome, ComError> seq
?totalSize : int64
?initialTimestamp : DateTime
Returns: JvLinkStub
|
|
Instance members
| Instance member |
Description
|
Full Usage:
this.ClearWatchEventFailure
|
Clears any configured WatchEvent failure. |
Full Usage:
this.ConfigureCourseFileResponse
Parameters:
string
explanation : string
|
|
Full Usage:
this.ConfigureCurrentReadFileSize
Parameters:
int64
|
|
Full Usage:
this.ConfigureJVLinkVersion
Parameters:
string
|
|
|
|
Full Usage:
this.ConfigurePayoffDialogSuppressed
Parameters:
bool
|
|
Full Usage:
this.ConfigureSaveFlag
Parameters:
bool
|
|
Full Usage:
this.ConfigureTotalReadFileSize
Parameters:
int64
|
Adjusts the synthetic `TotalReadFileSize` that the stub will expose.
|
|
Configures WatchEvent to fail with the specified error. Use to simulate COM event connection failures in tests.
|
Full Usage:
this.CurrentSavePath
Returns: string
|
|
|
Enqueues an additional response to be returned on subsequent `Read` calls.
|
|
|
|
|
Full Usage:
this.LastServiceKey
Returns: string option
|
|
Full Usage:
this.RaiseEvent
Parameters:
string
|
Helper to trigger a watch event callback during tests.
|
Full Usage:
this.UiDialogInvocationCount
Returns: int
|
|
Full Usage:
this.UseMovieAvailabilityResponder
Parameters:
string -> Result<MovieAvailability, ComError>
|
|
Full Usage:
this.UseMovieAvailabilityWithTypeResponder
Parameters:
string * string -> Result<MovieAvailability, ComError>
|
|
|
|
|
|
|
Static members
| Static member |
Description
|
|
Xanthos